import { EditorState, Extension, Compartment } from '@codemirror/state';
import { Line } from '@codemirror/text';
import { EditorView } from '@codemirror/view';
import prettier from 'prettier/standalone';
import { EditorConfigType } from './extensions';
export declare enum ThemeType {
    DARK = "dark",
    LIGHT = "light"
}
export declare enum EventType {
    FOCUS = "focus",
    BLUR = "blur",
    CHANGE = "change",
    SELECTCHANGE = "selectionChange",
    THEMECHANGE = "themeChange"
}
export declare type EventFunctionType = (value: string | Line, editor: BaseEditor) => void;
export interface BaseOptionsType {
    initValue?: string;
    editorConfig?: EditorConfigType;
    theme?: {
        def?: ThemeType;
        observer?: string | false;
        observerAttr?: string;
    };
}
declare class BaseEditor {
    parent: Element;
    state: EditorState;
    view: EditorView;
    extensions: Extension[];
    themeStatus: Compartment;
    theme: ThemeType;
    prettier: typeof prettier;
    options: BaseOptionsType;
    events: {
        [K in EventType[number]]: EventFunctionType;
    };
    constructor(options?: BaseOptionsType);
    create(parentExp: string, extensions?: Extension[]): void;
    changThemeHandler(theme: ThemeType): void;
    getValue(): string;
    setValue(val?: string): void;
    setEvent(type: EventType, handler: EventFunctionType): void;
    /**
     * 设置光标位置，以当前光标为基准，设置便宜量
     * @param offsetFrom number 开始点偏移量
     * @param offsetTo number 结束点偏移量
     */
    setCursor(offsetFrom: number, offsetTo: number): void;
    regExpcharacterEscape(str: string): string;
    $$(exp: string): Element | null;
    uuid(): string;
}
export default BaseEditor;
